@@ -4,13 +4,13 @@ var searchData=
   ['enablechangelistenernotification_1',['enableChangeListenerNotification',['../a01926.html#a01ee4368d1b29b8610baad98a3097cec',1,'cppu::OPropertySetHelper2']]],
   ['enablenonblockingmode_2',['enableNonBlockingMode',['../a00858.html#ada1ee513556e62e7058c522992ffcf13',1,'osl::Socket']]],
   ['encode_3',['encode',['../a00610.html#a1e84db69fd5b4b86a6a92b1eb547adb6',1,'rtl::Bootstrap::encode()'],['../a00746.html#acb69b2efad453d22779fe5ffa6d8f2a6',1,'rtl::Uri::encode(rtl::OUString const &amp;rText, sal_Bool const *pCharClass, rtl_UriEncodeMechanism eMechanism, rtl_TextEncoding eCharset)'],['../a00746.html#a448fa7e0d5403c180c1f59cae1867e77',1,'rtl::Uri::encode(rtl::OUString const &amp;rText, rtl_UriCharClass eCharClass, rtl_UriEncodeMechanism eMechanism, rtl_TextEncoding eCharset)']]],
-  ['end_4',['end',['../a01010.html#a6aa569da57fb65c4b001fec1e80fe902',1,'com::sun::star::uno::Sequence::end()'],['../a01010.html#aa6765e6c72caadf94d802a3f6280f770',1,'com::sun::star::uno::Sequence::end() const']]],
-  ['endswith_5',['endswith',['../a00666.html#ae74d8d826f8bb6590454135348454f85',1,'rtl::OString::endsWith(OString const &amp;str, OString *rest=NULL) const'],['../a00666.html#a124086ebe8d9159db2c703b030961ee6',1,'rtl::OString::endsWith(T &amp;literal, OString *rest=NULL) const'],['../a00754.html#a0a9dd4283c1651c8e0261077273d48dc',1,'rtl::OUString::endsWith(OUString const &amp;str, OUString *rest=NULL) const'],['../a00754.html#abd00c579b6f686891f4aa7d73f38c873',1,'rtl::OUString::endsWith(T &amp;literal, OUString *rest=NULL) const']]],
+  ['end_4',['end',['../a01010.html#a6aa569da57fb65c4b001fec1e80fe902',1,'com::sun::star::uno::Sequence::end()'],['../a01010.html#aa6765e6c72caadf94d802a3f6280f770',1,'com::sun::star::uno::Sequence::end() const'],['../a01010.html#a6aa569da57fb65c4b001fec1e80fe902',1,'com::sun::star::uno::Sequence&lt; bool &gt;::end()'],['../a01010.html#aa6765e6c72caadf94d802a3f6280f770',1,'com::sun::star::uno::Sequence&lt; bool &gt;::end() const']]],
+  ['endswith_5',['endsWith',['../a00666.html#ae74d8d826f8bb6590454135348454f85',1,'rtl::OString::endsWith(OString const &amp;str, OString *rest=NULL) const'],['../a00666.html#a124086ebe8d9159db2c703b030961ee6',1,'rtl::OString::endsWith(T &amp;literal, OString *rest=NULL) const'],['../a00754.html#a0a9dd4283c1651c8e0261077273d48dc',1,'rtl::OUString::endsWith(OUString const &amp;str, OUString *rest=NULL) const'],['../a00754.html#abd00c579b6f686891f4aa7d73f38c873',1,'rtl::OUString::endsWith(T &amp;literal, OUString *rest=NULL) const']]],
   ['endswithasciil_6',['endsWithAsciiL',['../a00754.html#a1dce9523dbc575f14cd2212cef2ddcdc',1,'rtl::OUString']]],
-  ['endswithignoreasciicase_7',['endswithignoreasciicase',['../a00754.html#a6a6bff8a9b0f6f4d5fc521ef9c459024',1,'rtl::OUString::endsWithIgnoreAsciiCase(OUString const &amp;str, OUString *rest=NULL) const'],['../a00754.html#ad6166e0daedd9662e4151e9f154138dd',1,'rtl::OUString::endsWithIgnoreAsciiCase(T &amp;literal, OUString *rest=NULL) const']]],
+  ['endswithignoreasciicase_7',['endsWithIgnoreAsciiCase',['../a00754.html#a6a6bff8a9b0f6f4d5fc521ef9c459024',1,'rtl::OUString::endsWithIgnoreAsciiCase(OUString const &amp;str, OUString *rest=NULL) const'],['../a00754.html#ad6166e0daedd9662e4151e9f154138dd',1,'rtl::OUString::endsWithIgnoreAsciiCase(T &amp;literal, OUString *rest=NULL) const']]],
   ['endswithignoreasciicaseasciil_8',['endsWithIgnoreAsciiCaseAsciiL',['../a00754.html#a0ccd5e8634080334c40d7dccbde3c878',1,'rtl::OUString']]],
   ['endswithl_9',['endsWithL',['../a00666.html#aafe10051a30b4ba77dbee8b096a0c421',1,'rtl::OString']]],
-  ['ensurecapacity_10',['ensurecapacity',['../a00662.html#a926ea93d243f4fcab5c01c3a6672ebb4',1,'rtl::OStringBuffer::ensureCapacity()'],['../a00750.html#ac0749937b466886d614acc4e144a2cfc',1,'rtl::OUStringBuffer::ensureCapacity()']]],
+  ['ensurecapacity_10',['ensureCapacity',['../a00662.html#a926ea93d243f4fcab5c01c3a6672ebb4',1,'rtl::OStringBuffer::ensureCapacity()'],['../a00750.html#ac0749937b466886d614acc4e144a2cfc',1,'rtl::OUStringBuffer::ensureCapacity()']]],
   ['enter_11',['enter',['../a00982.html#afefdf7e25ee12121ee133161a6d0cf7a',1,'com::sun::star::uno::Environment::enter()'],['../a00994.html#a21a802ef1b6d3b4b52a370deed148731',1,'cppu::Enterable::enter()']]],
   ['enterable_12',['Enterable',['../a00994.html#ac0de3fa18a9bc16ae90ede2a2ee046f2',1,'cppu::Enterable']]],
   ['enterable_5fcall_5fcallinto_5fv_13',['Enterable_call_callInto_v',['../a00537.html#aaf16fcbae344040f79a7bfb7b58db472',1,'cppu']]],
@@ -19,12 +19,12 @@ var searchData=
   ['enterable_5fcall_5fisvalid_16',['Enterable_call_isValid',['../a00537.html#a6af9bf435c6a006cfe84fd87b3ba0f4d',1,'cppu']]],
   ['enterable_5fcall_5fleave_17',['Enterable_call_leave',['../a00537.html#ae497668d91aa3754adb4189fefc5d2e8',1,'cppu']]],
   ['envguard_18',['EnvGuard',['../a00998.html#adabaaf6b5a8445668f0725cfe86fa02a',1,'cppu::EnvGuard']]],
-  ['environment_19',['environment',['../a00982.html#a52c8a36837ad58e98784f549cd95b3ed',1,'com::sun::star::uno::Environment::Environment(uno_Environment *pEnv=NULL)'],['../a00982.html#a1224d0b31212c4465973b6652dd4c504',1,'com::sun::star::uno::Environment::Environment(rtl::OUString const &amp;envDcp, void *pContext=NULL)'],['../a00982.html#a76d19e18ab8d0d898fb552cba029e0d9',1,'com::sun::star::uno::Environment::Environment(const Environment &amp;rEnv)']]],
+  ['environment_19',['Environment',['../a00982.html#a52c8a36837ad58e98784f549cd95b3ed',1,'com::sun::star::uno::Environment::Environment(uno_Environment *pEnv=NULL)'],['../a00982.html#a1224d0b31212c4465973b6652dd4c504',1,'com::sun::star::uno::Environment::Environment(rtl::OUString const &amp;envDcp, void *pContext=NULL)'],['../a00982.html#a76d19e18ab8d0d898fb552cba029e0d9',1,'com::sun::star::uno::Environment::Environment(const Environment &amp;rEnv)']]],
   ['environment_5finitwithenterable_20',['Environment_initWithEnterable',['../a00540.html#a6acec576bc79a431fd632b7a73a65f3e',1,'cppu::helper::purpenv']]],
-  ['equals_21',['equals',['../a00950.html#a9234418ef5a517af5c6e6f0b1d55f35a',1,'com::sun::star::uno::TypeDescription::equals()'],['../a00666.html#ae8c738b6b1acf0209996a759000f4529',1,'rtl::OString::equals()'],['../a00754.html#af8906c3531fdab1b1ea30ffec22bbc15',1,'rtl::OUString::equals()'],['../a00950.html#ac9a86d17cc6ae80b74f0c2a104f3e9ca',1,'com::sun::star::uno::TypeDescription::equals()'],['../a01974.html#a551931cdcaa98bceedd76d8206d80521',1,'com::sun::star::uno::Type::equals()']]],
+  ['equals_21',['equals',['../a00666.html#ae8c738b6b1acf0209996a759000f4529',1,'rtl::OString::equals()'],['../a00754.html#af8906c3531fdab1b1ea30ffec22bbc15',1,'rtl::OUString::equals()'],['../a00950.html#a9234418ef5a517af5c6e6f0b1d55f35a',1,'com::sun::star::uno::TypeDescription::equals(const typelib_TypeDescription *pTypeDescr) const'],['../a00950.html#ac9a86d17cc6ae80b74f0c2a104f3e9ca',1,'com::sun::star::uno::TypeDescription::equals(const TypeDescription &amp;rTypeDescr) const'],['../a01974.html#a551931cdcaa98bceedd76d8206d80521',1,'com::sun::star::uno::Type::equals()']]],
   ['equalsascii_22',['equalsAscii',['../a00754.html#a975abdfbab9e0c78c10307df1a5ebaa7',1,'rtl::OUString']]],
   ['equalsasciil_23',['equalsAsciiL',['../a00754.html#a5e2609800c4992774b08c8a7d2c07436',1,'rtl::OUString']]],
-  ['equalsignoreasciicase_24',['equalsignoreasciicase',['../a00666.html#adbbf466e411d68099894f0511fa49ca1',1,'rtl::OString::equalsIgnoreAsciiCase(const T &amp;asciiStr) const'],['../a00666.html#ace69f01af1e5bbd09d6fde970254f4b9',1,'rtl::OString::equalsIgnoreAsciiCase(const OString &amp;str) const'],['../a00754.html#a51cd29980d7962cc7c5fce9781ea27b3',1,'rtl::OUString::equalsIgnoreAsciiCase(T &amp;literal) const'],['../a00754.html#a19c4188312d907a6267d9ca435ff0e84',1,'rtl::OUString::equalsIgnoreAsciiCase(const OUString &amp;str) const'],['../a00666.html#a41b89297b85dc79db79bd2d91172975b',1,'rtl::OString::equalsIgnoreAsciiCase(T &amp;literal) const'],['../a00666.html#ad757daff373e4845cd7930a8af3eef98',1,'rtl::OString::equalsIgnoreAsciiCase(T &amp;asciiStr) const']]],
+  ['equalsignoreasciicase_24',['equalsIgnoreAsciiCase',['../a00666.html#ace69f01af1e5bbd09d6fde970254f4b9',1,'rtl::OString::equalsIgnoreAsciiCase(const OString &amp;str) const'],['../a00666.html#adbbf466e411d68099894f0511fa49ca1',1,'rtl::OString::equalsIgnoreAsciiCase(const T &amp;asciiStr) const'],['../a00666.html#ad757daff373e4845cd7930a8af3eef98',1,'rtl::OString::equalsIgnoreAsciiCase(T &amp;asciiStr) const'],['../a00666.html#a41b89297b85dc79db79bd2d91172975b',1,'rtl::OString::equalsIgnoreAsciiCase(T &amp;literal) const'],['../a00754.html#a19c4188312d907a6267d9ca435ff0e84',1,'rtl::OUString::equalsIgnoreAsciiCase(const OUString &amp;str) const'],['../a00754.html#a51cd29980d7962cc7c5fce9781ea27b3',1,'rtl::OUString::equalsIgnoreAsciiCase(T &amp;literal) const']]],
   ['equalsignoreasciicaseascii_25',['equalsIgnoreAsciiCaseAscii',['../a00754.html#aad245e6979066dc481bd116d413e7cf8',1,'rtl::OUString']]],
   ['equalsignoreasciicaseasciil_26',['equalsIgnoreAsciiCaseAsciiL',['../a00754.html#a2245d3d40c15586202e3f953c1a7cfbc',1,'rtl::OUString']]],
   ['equalsignoreasciicasel_27',['equalsIgnoreAsciiCaseL',['../a00666.html#afa008446aca7017ee3bfa130eeba6be1',1,'rtl::OString']]],
